@@ -98,10 +98,9 @@ class DaemonApplication(object):
         def show_config_filepaths():
             """Print out the config searching paths.
             """
-            paths, default = fsutils.get_application_config_paths(self.get_appname())
+            paths = fsutils.get_application_config_paths(self.get_appname())
             print("Application will search config file from follow paths. It will load the first exists file as the config file.")
             for path in paths:
                 print("    ", os.path.abspath(path))
-            print("    ", os.path.abspath(default))
 
         return main
